// This is based on the code framework of Fuzzy Clock by dallagi
// Changes the default clock to display a week view instead of the day of week
// Ex.: Monday March 19, 2012 would display: 18 19 T W T F 24
//      and the 19 would be bold, the rest unbold.

const St = imports.gi.St;
const Main = imports.ui.main;
const Mainloop = imports.mainloop;
const Lang = imports.lang;

const UPDATE_INTERVAL = 5000; // every 5 seconds

function WeekClock() {
    this._init();
}

WeekClock.prototype = {
    _init: function() {
        this.date_menu = Main.panel._dateMenu;
        this.orig_clock = this.date_menu._clock;
        this.week_clock = new St.BoxLayout();
        this.week_left = new St.Label({ style_class: 'week-all' });
        this.week_center = new St.Label({ style_class: 'week-today' });
        this.week_right = new St.Label({ style_class: 'week-all' });
        this.time_text = new St.Label({ style_class: 'week-time' });
        this.week_clock.add(this.week_left);
        this.week_clock.add(this.week_center);
        this.week_clock.add(this.week_right);
        this.week_clock.add(this.time_text);
        this.timeout = null;
    },

    WeekText: function() {
        let now = new Date();
        let sun = new Date();
        let sat = new Date();
        today = now.getDate();
        dow = now.getDay(); // day of week
        sun.setDate(today-dow);
        sat.setDate(today-dow+6);
        week = ["S","M","T","W","T","F","S"];
        week[dow] = today;
        week[0] = sun.getDate();
        week[6] = sat.getDate();

        // set text for days before today (unbolded)
        calendar = "";
        for (let i = 0; i < dow; i++) {
            if (i > 0) {
                calendar = calendar + " ";
            }
            calendar = calendar + week[i];
        }

        // set text for today (bold)
        this.week_left.set_text(calendar);

        // set text for days after today (unbolded)
        this.week_center.set_text(" "+today+" ");
        calendar = "";
        for (let i = dow + 1; i < 7; i++) {
            calendar = calendar + week[i];
            calendar = calendar + " ";
        }
        this.week_right.set_text(calendar);

        // set time
        hours = (now.getHours()+11)%12+1;
        minutes = now.getMinutes();
        if (minutes < 10) {
            minutes = "0" + minutes;
        }
        if (now.getHours() >= 12) {
            ampm = "PM";
        } else {
            ampm = "AM";
        }
        this.time_text.set_text(" "+hours+":"+minutes+" "+ampm);
    },

    on_timeout: function() {
        this.WeekText();

        return this.run;
    },

    enable: function() {
        this.date_menu.actor.remove_actor(this.orig_clock);
        this.date_menu.actor.add_actor(this.week_clock);

        this.run = true;
        this.on_timeout();
        this.timeout = Mainloop.timeout_add(UPDATE_INTERVAL, Lang.bind(this, this.on_timeout));
    },

    disable: function() {
        this.run = false;
        MainLoop.source_remove(this.timeout);

        this.date_menu.actor.remove_actor(this.week_clock);
        this.date_menu.actor.add_actor(this.orig_clock);
    }
}

function init() {
    return new WeekClock();
}
// vim: expandtab softtabstop=4
